Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/core
diff options
context:
space:
mode:
authorMatthieu Aubry <mattab@users.noreply.github.com>2017-11-20 03:18:06 +0300
committerGitHub <noreply@github.com>2017-11-20 03:18:06 +0300
commitfd53c52d115b08db8135adc475b9c7fa85c4fcd1 (patch)
tree107bc51160ca8b9b8e348e9eb66c8f11ddcb5014 /core
parentf149d7738831b74631c6dd336ed1333f88c66e6e (diff)
Log on DEBUG level all SQL archiving queries (#12257)
As long as it does not create performance regression or impact, it would be really useful to have this by default in Piwik, makes it useful to troubleshoot archiving problems without having to patch this file and uncomment this logger line.
Diffstat (limited to 'core')
-rw-r--r--core/DataAccess/LogAggregator.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/core/DataAccess/LogAggregator.php b/core/DataAccess/LogAggregator.php
index ede9f81526..ac87149c69 100644
--- a/core/DataAccess/LogAggregator.php
+++ b/core/DataAccess/LogAggregator.php
@@ -185,8 +185,8 @@ class LogAggregator
$query['sql'] = 'SELECT /* ' . $this->queryOriginHint . ' */' . substr($query['sql'], strlen($select));
}
- // Uncomment to log on DEBUG level all archiving queries
- // $this->logger->debug($query['sql']);
+ // Log on DEBUG level all SQL archiving queries
+ $this->logger->debug($query['sql']);
return $query;
}